@@ -107,7 +107,7 @@ static rtems_isr
 mcf5235_fec_rx_interrupt_handler( rtems_vector_number v )
 {
     MCF5235_FEC_EIR = MCF5235_FEC_EIR_RXF;
-    MCF5235_FEC_EIMR &= ~MCF5235_FEC_EIMR_RXF;    
+    MCF5235_FEC_EIMR &= ~MCF5235_FEC_EIMR_RXF;
     enet_driver[0].rxInterrupts++;
     rtems_event_send(enet_driver[0].rxDaemonTid, RX_INTERRUPT_EVENT);
 }
@@ -116,7 +116,7 @@ static rtems_isr
 mcf5235_fec_tx_interrupt_handler( rtems_vector_number v )
 {
     MCF5235_FEC_EIR = MCF5235_FEC_EIR_TXF;
-    MCF5235_FEC_EIMR &= ~MCF5235_FEC_EIMR_TXF;    
+    MCF5235_FEC_EIMR &= ~MCF5235_FEC_EIMR_TXF;
     enet_driver[0].txInterrupts++;
     rtems_event_send(enet_driver[0].txDaemonTid, TX_INTERRUPT_EVENT);
 }
@@ -240,7 +240,7 @@ mcf5235_fec_initialize_hardware(struct mcf5235_enet_struct *sc)
      *   Full duplex
      *   No loopback
      */
-    MCF5235_FEC_RCR = MCF5235_FEC_RCR_MAX_FL(MAX_MTU_SIZE) | 
+    MCF5235_FEC_RCR = MCF5235_FEC_RCR_MAX_FL(MAX_MTU_SIZE) |
                       MCF5235_FEC_RCR_MII_MODE;
 
     /*
@@ -307,6 +307,28 @@ mcf5235_fec_initialize_hardware(struct mcf5235_enet_struct *sc)
     MCF5235_INTC0_IMRL &= ~(MCF5235_INTC0_IMRL_INT27 | MCF5235_INTC0_IMRL_MASKALL);
 }
 
+/*
+ * Get the MAC address from the hardware.
+ */
+static void
+fec_get_mac_address(volatile struct mcf5235_enet_struct *sc, unsigned char* hwaddr)
+{
+  unsigned long addr;
+
+  addr = MCF5235_FEC_PALR;
+
+  hwaddr[0] = (addr >> 24) & 0xff;
+  hwaddr[1] = (addr >> 16) & 0xff;
+  hwaddr[2] = (addr >>  8) & 0xff;
+  hwaddr[3] = (addr >>  0) & 0xff;
+
+  addr = MCF5235_FEC_PAUR;
+
+  hwaddr[4] = (addr >> 24) & 0xff;
+  hwaddr[5] = (addr >> 16) & 0xff;
+}
+
+
 /*
  * Soak up buffer descriptors that have been sent.
  */
@@ -463,9 +485,9 @@ fec_sendpacket(struct ifnet *ifp, struct mbuf *m)
      */
     nAdded = 0;
     firstTxBd = sc->txBdBase + sc->txBdHead;
-    
+
     for (;;) {
-        /* 
+        /*
          * Wait for buffer descriptor to become available
          */
         if ((sc->txBdActiveCount + nAdded)  == sc->txBdCount) {
@@ -486,7 +508,7 @@ fec_sendpacket(struct ifnet *ifp, struct mbuf *m)
                 int level;
 
                 rtems_interrupt_disable(level);
-                MCF5235_FEC_EIMR |= MCF5235_FEC_EIMR_TXF;    
+                MCF5235_FEC_EIMR |= MCF5235_FEC_EIMR_TXF;
                 rtems_interrupt_enable(level);
                 sc->txRawWait++;
                 rtems_bsdnet_event_receive(TX_INTERRUPT_EVENT,
@@ -496,13 +518,13 @@ fec_sendpacket(struct ifnet *ifp, struct mbuf *m)
                 fec_retire_tx_bd(sc);
             }
         }
-    
+
         /*
          * Don't set the READY flag on the first fragment
          * until the whole packet has been readied.
          */
         status = nAdded ? MCF5235_FEC_TxBD_R : 0;
-    
+
         /*
          * The IP fragmentation routine in ip_output
          * can produce fragments with zero length.
@@ -573,9 +595,9 @@ fec_txDaemon(void *arg)
         /*
          * Wait for packet
          */
-        rtems_bsdnet_event_receive(START_TRANSMIT_EVENT, 
-                                    RTEMS_EVENT_ANY | RTEMS_WAIT, 
-                                    RTEMS_NO_TIMEOUT, 
+        rtems_bsdnet_event_receive(START_TRANSMIT_EVENT,
+                                    RTEMS_EVENT_ANY | RTEMS_WAIT,
+                                    RTEMS_NO_TIMEOUT,
                                     &events);
 
         /*
@@ -789,26 +811,30 @@ rtems_fec_driver_attach(struct rtems_bsdnet_ifconfig *config, int attaching )
     /*
      * Is driver free?
      */
-    if ((unitNumber <= 0) || (unitNumber > NIFACES)) {
-        printf("Bad FEC unit number.\n");
+    if ((unitNumber < 0) || (unitNumber >= NIFACES)) {
+        printf("mcf5235: bad FEC unit number.\n");
         return 0;
     }
-    sc = &enet_driver[unitNumber - 1];
+    sc = &enet_driver[unitNumber];
     ifp = &sc->arpcom.ac_if;
     if (ifp->if_softc != NULL) {
-        printf("Driver already in use.\n");
+        printf("mcf5235: driver already in use.\n");
         return 0;
     }
 
     /*
      * Process options
      */
+    if (config->hardware_address)
+      memcpy(sc->arpcom.ac_enaddr, config->hardware_address, ETHER_ADDR_LEN);
+    else
+      fec_get_mac_address(sc, sc->arpcom.ac_enaddr);
+
     hwaddr = config->hardware_address;
-    printf("%s%d: Ethernet address: %02x:%02x:%02x:%02x:%02x:%02x\n",
-                                            unitName, unitNumber,
-                                            hwaddr[0], hwaddr[1], hwaddr[2],
-                                            hwaddr[3], hwaddr[4], hwaddr[5]);
-    memcpy(sc->arpcom.ac_enaddr, hwaddr, ETHER_ADDR_LEN);
+    printf("%s%d: mac: %02x:%02x:%02x:%02x:%02x:%02x\n",
+           unitName, unitNumber,
+           hwaddr[0], hwaddr[1], hwaddr[2],
+           hwaddr[3], hwaddr[4], hwaddr[5]);
 
     if (config->mtu)
         mtu = config->mtu;
