@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  @(#) $Id: msdos_handlers_file.c,v 1.3 2004/04/17 08:34:40 ralf Exp $
+ *  @(#) $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -18,7 +18,7 @@
 #include <rtems/libio.h>
 #include "msdos.h"
 
-rtems_filesystem_file_handlers_r msdos_file_handlers = {
+const rtems_filesystem_file_handlers_r msdos_file_handlers = {
     msdos_file_open,
     msdos_file_close,
     msdos_file_read,
@@ -26,7 +26,7 @@ rtems_filesystem_file_handlers_r msdos_file_handlers = {
     msdos_file_ioctl,
     msdos_file_lseek,
     msdos_file_stat,
-    NULL,
+    msdos_file_chmod,
     msdos_file_ftruncate,
     NULL,
     msdos_file_sync,
