@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: imfs_handlers_memfile.c,v 1.10 2005/02/08 17:12:54 ericn Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -23,7 +23,7 @@
  *  Set of operations handlers for operations on memfile entities.
  */
 
-rtems_filesystem_file_handlers_r IMFS_memfile_handlers = {
+const rtems_filesystem_file_handlers_r IMFS_memfile_handlers = {
   memfile_open,
   memfile_close,
   memfile_read,
