@@ -3,15 +3,24 @@
  */
 
 /*
- * $Id: cpu.h,v 1.26 2007/05/09 15:28:43 ralf Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ * $Id$
  */
- 
+
 #ifndef _RTEMS_SCORE_CPU_H
 #define _RTEMS_SCORE_CPU_H
 
 #include <rtems/score/powerpc.h>              /* pick up machine definitions */
+
 #ifndef ASM
-#include <rtems/score/types.h>
+  #include <string.h> /* for memset() */
+  #include <rtems/score/types.h>
 #endif
 
 /* conditional compilation parameters */
@@ -109,7 +118,7 @@
  */
 
 #define CPU_STRUCTURE_ALIGNMENT \
-  __attribute__ ((aligned (PPC_CACHE_ALIGNMENT)))
+  __attribute__ ((aligned (PPC_STRUCTURE_ALIGNMENT)))
 
 /*
  *  Define what is required to specify how the network to host conversion
@@ -217,6 +226,7 @@
  */
 
 #ifndef ASM
+
 typedef struct {
     uint32_t   gpr1;	/* Stack pointer for all */
     uint32_t   gpr2;	/* Reserved SVR4, section ptr EABI + */
@@ -242,8 +252,24 @@ typedef struct {
     uint32_t   cr;	/* PART of the CR is non volatile for all */
     uint32_t   pc;	/* Program counter/Link register */
     uint32_t   msr;	/* Initial interrupt level */
+#ifdef __ALTIVEC__
+	/* 12 non-volatile vector registers, cache-aligned area for vscr/vrsave
+	 * and padding to ensure cache-alignment.
+	 * Unfortunately, we can't verify the cache line size here
+	 * in the cpukit but altivec support code will produce an
+	 * error if this is ever different from 32 bytes.
+	 * 
+	 * Note: it is the BSP/CPU-support's responsibility to
+	 *       save/restore volatile vregs across interrupts
+	 *       and exceptions.
+	 */
+	uint8_t    altivec[16*12 + 32 + 32];
+#endif
 } Context_Control;
 
+#define _CPU_Context_Get_SP( _context ) \
+  (_context)->gpr1
+
 typedef struct {
     /* The ABIs (PowerOpen/SVR4/EABI) only require saving f14-f31 over
      * procedure calls.  However, this would mean that the interrupt
@@ -253,15 +279,13 @@ typedef struct {
      */
 #if (PPC_HAS_DOUBLE == 1)
     double	f[32];
-    double	fpscr;
+    uint64_t	fpscr;
 #else
     float	f[32];
-    float	fpscr;
+    uint32_t	fpscr;
 #endif
 } Context_Control_fp;
-#endif /* ASM */
 
-#ifndef ASM
 typedef struct CPU_Interrupt_frame {
     uint32_t   stacklink;	/* Ensure this is a real frame (also reg1 save) */
     uint32_t   calleeLr;	/* link register used by callees: SVR4/EABI */
@@ -292,13 +316,10 @@ typedef struct CPU_Interrupt_frame {
     uint32_t   msr;
     uint32_t   pad[3];
 } CPU_Interrupt_frame;
+
 #endif /* ASM */
 
-#ifdef _OLD_EXCEPTIONS
-#include <rtems/old-exceptions/cpu.h>
-#else
 #include <rtems/new-exceptions/cpu.h>
-#endif
 
 /*
  *  Should be large enough to run all RTEMS tests.  This ensures
@@ -373,13 +394,13 @@ typedef struct CPU_Interrupt_frame {
  *  endianness for ALL fetches -- both code and data -- so the code
  *  will be fetched incorrectly.
  */
- 
+
 static inline uint32_t CPU_swap_u32(
   uint32_t value
 )
 {
   uint32_t   swapped;
- 
+
   asm volatile("rlwimi %0,%1,8,24,31;"
 	       "rlwimi %0,%1,24,16,23;"
 	       "rlwimi %0,%1,8,8,15;"
@@ -394,135 +415,6 @@ static inline uint32_t CPU_swap_u32(
 
 #endif /* ASM */
 
-#ifndef ASM
-/*
- *  Macros to access PowerPC specific additions to the CPU Table
- */
-
-#define rtems_cpu_configuration_get_clicks_per_usec() \
-   (_CPU_Table.clicks_per_usec)
-
-#define rtems_cpu_configuration_get_exceptions_in_ram() \
-   (_CPU_Table.exceptions_in_RAM)
-
-#if (defined(ppc403) || defined(ppc405) \
-  || defined(mpc860) || defined(mpc821) || defined(mpc8260))
-
-#define rtems_cpu_configuration_get_serial_per_sec() \
-   (_CPU_Table.serial_per_sec)
-
-#define rtems_cpu_configuration_get_serial_external_clock() \
-   (_CPU_Table.serial_external_clock)
-
-#define rtems_cpu_configuration_get_serial_xon_xoff() \
-   (_CPU_Table.serial_xon_xoff)
-
-#define rtems_cpu_configuration_get_serial_cts_rts() \
-   (_CPU_Table.serial_cts_rts)
-
-#define rtems_cpu_configuration_get_serial_rate() \
-   (_CPU_Table.serial_rate)
-
-#define rtems_cpu_configuration_get_timer_average_overhead() \
-   (_CPU_Table.timer_average_overhead)
-
-#define rtems_cpu_configuration_get_timer_least_valid() \
-   (_CPU_Table.timer_least_valid)
-
-#define rtems_cpu_configuration_get_timer_internal_clock() \
-   (_CPU_Table.timer_internal_clock)
-
-#endif
-
-#if (defined(mpc555) \
-  || defined(mpc860) || defined(mpc821) || defined(mpc8260))
-#define rtems_cpu_configuration_get_clock_speed() \
-   (_CPU_Table.clock_speed)
-#endif
-
-#endif /* ASM */
-
-#ifndef ASM
-/*
- *  Simple spin delay in microsecond units for device drivers.
- *  This is very dependent on the clock speed of the target.
- */
-
-#define CPU_Get_timebase_low( _value ) \
-    asm volatile( "mftb  %0" : "=r" (_value) )
-
-#define rtems_bsp_delay( _microseconds ) \
-  do { \
-    uint32_t   start, ticks, now; \
-    CPU_Get_timebase_low( start ) ; \
-    ticks = (_microseconds) * rtems_cpu_configuration_get_clicks_per_usec(); \
-    do \
-      CPU_Get_timebase_low( now ) ; \
-    while (now - start < ticks); \
-  } while (0)
-
-#define rtems_bsp_delay_in_bus_cycles( _cycles ) \
-  do { \
-    uint32_t   start, now; \
-    CPU_Get_timebase_low( start ); \
-    do \
-      CPU_Get_timebase_low( now ); \
-    while (now - start < (_cycles)); \
-  } while (0)
-
-#endif /* ASM */
-
-#ifndef ASM
-/*
- *  Routines to access the decrementer register
- */
-
-#define PPC_Set_decrementer( _clicks ) \
-  do { \
-    asm volatile( "mtdec %0" : : "r" ((_clicks)) ); \
-  } while (0)
-
-#define PPC_Get_decrementer( _clicks ) \
-    asm volatile( "mfdec  %0" : "=r" (_clicks) )
-
-#endif /* ASM */
-
-#ifndef ASM
-/*
- *  Routines to access the time base register
- */
-
-static inline uint64_t PPC_Get_timebase_register( void )
-{
-  uint32_t tbr_low;
-  uint32_t tbr_high;
-  uint32_t tbr_high_old;
-  uint64_t tbr;
-
-  do {
-    asm volatile( "mftbu %0" : "=r" (tbr_high_old));
-    asm volatile( "mftb  %0" : "=r" (tbr_low));
-    asm volatile( "mftbu %0" : "=r" (tbr_high));
-  } while ( tbr_high_old != tbr_high );
-
-  tbr = tbr_high;
-  tbr <<= 32;
-  tbr |= tbr_low;
-  return tbr;
-}
-
-static inline  void PPC_Set_timebase_register (uint64_t tbr)
-{
-  uint32_t tbr_low;
-  uint32_t tbr_high;
-
-  tbr_low = (tbr & 0xffffffff) ;
-  tbr_high = (tbr >> 32) & 0xffffffff;
-  asm volatile( "mtspr 284, %0" : : "r" (tbr_low));
-  asm volatile( "mtspr 285, %0" : : "r" (tbr_high));
-  
-}
-#endif /* ASM */
 
 #ifndef ASM
 /* Context handler macros */
@@ -549,7 +441,7 @@ void _CPU_Context_Initialize(
   uint32_t          size,
   uint32_t          new_level,
   void             *entry_point,
-  boolean           is_fp
+  bool              is_fp
 );
 
 /*
@@ -595,9 +487,7 @@ void _CPU_Context_Initialize(
  */
 
 #define _CPU_Context_Initialize_fp( _destination ) \
-  { \
-    (*(_destination))->fpscr = PPC_INIT_FPSCR; \
-  }
+  memset( *(_destination), 0, sizeof( **(_destination) ) )
 
 /* end of Context handler macros */
 #endif /* ASM */
@@ -700,10 +590,7 @@ void _CPU_Context_Initialize(
  *  This routine performs CPU dependent initialization.
  */
 
-void _CPU_Initialize(
-  rtems_cpu_table  *cpu_table,
-  void            (*thread_dispatch)
-);
+void _CPU_Initialize(void);
 
 /*
  *  _CPU_ISR_install_vector
@@ -772,6 +659,48 @@ void _CPU_Context_restore_fp(
   Context_Control_fp **fp_context_ptr
 );
 
+/*
+ * _CPU_Initialize_altivec()
+ *
+ * Global altivec-related initialization.
+ */
+void
+_CPU_Initialize_altivec(void);
+
+/*
+ * _CPU_Context_switch_altivec
+ *
+ * This routine switches the altivec contexts passed to it.
+ */
+
+void
+_CPU_Context_switch_altivec(
+  Context_Control *from,
+  Context_Control *to
+);
+
+/*
+ * _CPU_Context_restore_altivec
+ *
+ * This routine restores the altivec context passed to it.
+ */
+
+void
+_CPU_Context_restore_altivec(
+  Context_Control *ctxt
+);
+
+/*
+ * _CPU_Context_initialize_altivec
+ *
+ * This routine initializes the altivec context passed to it.
+ */
+
+void
+_CPU_Context_initialize_altivec(
+  Context_Control *ctxt
+);
+
 void _CPU_Fatal_error(
   uint32_t   _error
 );
