@@ -15,12 +15,12 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: tcreate.c,v 1.11 2004/04/16 09:19:06 ralf Exp $
+ *  $Id$
  */
 
 #include "system.h"
 
-rtems_boolean Task_create_extension(
+bool Task_create_extension(
   rtems_tcb *unused,
   rtems_tcb *created_task
 )
@@ -30,11 +30,17 @@ rtems_boolean Task_create_extension(
 
   if ( task_number( created_task->Object.id ) > 0 ) {
     name = Task_name[ task_number( created_task->Object.id ) ];
+/*
+ * FIXME: There should be a public function to
+ * convert numeric rtems_names into char arrays
+ * c.f. rtems_name_to_characters() in rtems/rtems/support.inl
+ * but it's private.
+ */
     sprintf( line, "TASK_CREATE - %c%c%c%c - created\n",
-      (name >> 24) & 0xff,
-      (name >> 16) & 0xff,
-      (name >> 8) & 0xff,
-      name & 0xff
+      (char)((name >> 24) & 0xff),
+      (char)((name >> 16) & 0xff),
+      (char)((name >> 8) & 0xff),
+      (char)(name & 0xff)
     );
     buffered_io_add_string( line );
   }
